@@ -1,4 +1,5 @@
 from je_api_testka.requests_wrapper.requests_data_structure import api_tester_method
+from requests.structures import CaseInsensitiveDict
 
 from je_api_testka.utils.exception.api_test_exceptions import APITesterException
 from je_api_testka.utils.exception.api_test_exceptions import APITesterGetDataException
@@ -15,6 +16,7 @@ from je_api_testka.utils.exception.api_test_eceptions_tag import api_test_option
 from je_api_testka.utils.exception.api_test_eceptions_tag import api_test_patch_error_message
 from je_api_testka.utils.exception.api_test_eceptions_tag import api_test_session_error_message
 
+from je_api_testka.record.record import record
 
 exception_message_dict = {
     "get": api_test_get_error_message,
@@ -35,7 +37,7 @@ exception_message_dict = {
 }
 
 
-def get_response(response, get_json=False):
+def get_response(response, get_json: bool = False):
     if get_json:
         response_data = {
             "status_code": response.status_code,
@@ -49,7 +51,18 @@ def get_response(response, get_json=False):
             raise APITesterGetDataException(api_test_get_data_error_message)
 
 
-def test_api_method(http_method: str, test_url: str, get_json=False, **kwargs):
-    response = api_tester_method(http_method, test_url=test_url, **kwargs)
+def test_api_method(http_method: str, test_url: str, get_json: bool = False,
+                    soap: bool = False, record_request_info: bool = True,
+                    clean_record: bool = False, **kwargs):
+    if soap is False:
+        response = api_tester_method(http_method, test_url=test_url, **kwargs)
+    else:
+        headers = CaseInsensitiveDict()
+        headers["Content-Type"] = "application/soap+xml"
+        return test_api_method(http_method, test_url=test_url, headers=headers, **kwargs)
     response_data = get_response(response, get_json)
+    if record_request_info:
+        record.record_list.append(response_data)
+    elif clean_record:
+        record.clean_record()
     return {"response": response, "response_data": response_data}
